#!/usr/bin/sh

# Extract Remote System Explorer server jar file

# convert from dos to unix format and set permissions
setPermissions () {
	chmod 755 daemon.aix
	chmod 755 server.aix
	chmod 755 daemon.unix
	chmod 755 server.unix
	chmod 755 auth.pl
	chmod -R 755 debug/.
        chmod 755 rseterm/rseterm
}

# parent directory, which must exist
if [ $# -eq 0 ]
then
        PARENT_DIR_PATH="/opt"
else
        PARENT_DIR_PATH=$1
fi


# server directory name
SERVER_DIR_NAME="rseserver630"

# jar file name
SERVER_FILE_NAME="rseserver.jar"

# debug engine file name
DEBUG_ENGINE_FILE_NAME="aix_engine.zip"

# check if parent directory exists. If not, quit.
if [ ! -d $PARENT_DIR_PATH ]; then

	# create parent directory
	mkdir $PARENT_DIR_PATH

	# if parent directory still doesn't exist, something was wrong (e.g. don't have permission), so quit.
	if [ ! -d $PARENT_DIR_PATH ]; then
		exit 1
	fi

fi

# create server directory path
SERVER_DIR_PATH=$PARENT_DIR_PATH"/"$SERVER_DIR_NAME

# check server directory. If it doesn't exist, create it in a subshell.
if [ ! -d $SERVER_DIR_PATH ]; then

	(cd $PARENT_DIR_PATH && mkdir $SERVER_DIR_NAME)

	# if server directory still doesn't exist, something was wrong (e.g. don't have permission), so quit.
	if [ ! -d $SERVER_DIR_PATH ]; then
	exit 1
	fi

fi

# copy server jar file to server directory, extract the jar,
cp $SERVER_FILE_NAME $SERVER_DIR_PATH"/." && cd $SERVER_DIR_PATH && jar -xf $SERVER_FILE_NAME 

# extract debug engine tar file
cd debug
unzip $DEBUG_ENGINE_FILE_NAME
rm $DEBUG_ENGINE_FILE_NAME

# set permissions
cd ../
setPermissions

exit 0
